import React from "react"
import { graphql, useStaticQuery } from "gatsby"

import { ChevronRightIcon, ChevronDownIcon } from "@heroicons/react/solid"

import { Link } from "@onegeo-suite/gatsby-theme-onegeo"
import { UserMenu } from "@onegeo-suite/gatsby-plugin-auth"
import { twMerge } from "tailwind-merge"

interface Imenu {
    className?: string
    name: string
    userMenu?: boolean
    options: any
}
const Menu = (props: Imenu) => {
    const { className, name, userMenu = false } = props

    const data = useStaticQuery(graphql`
        fragment MenuItem on DirectusData_menus {
            sort
            name
            type
            url
            page {
                slug
            }
            options
        }

        fragment MenusRecursive on DirectusData_menus {
            children(filter: { status: { _eq: "published" } }, sort: "sort") {
                ...MenuItem
                children(
                    filter: { status: { _eq: "published" } }
                    sort: "sort"
                ) {
                    ...MenuItem
                    children(
                        filter: { status: { _eq: "published" } }
                        sort: "sort"
                    ) {
                        ...MenuItem
                    }
                }
            }
        }

        query Menus {
            directus {
                menus(
                    filter: {
                        status: { _eq: "published" }
                        parent_id: { id: { _null: true } }
                    }
                    sort: "sort"
                ) {
                    sort
                    name
                    options
                    ...MenusRecursive
                }
            }
        }
    `)

    const menuContent = data.directus.menus
    // const oClass = options || {}
    // const option = props.options ?? {}
    const options = props.options ?? {}
    const oClass = options.class || {}
    const oItem = oClass.items || {}
    const oSubitem = oClass.subitems || {}

    const menu =
        menuContent.find(
            (menu: any) => name?.toLowerCase() === menu.name?.toLowerCase()
        )?.children || []

    // menuContent.map((m) =>{
    //     console.log(m.children)
    // })

    const goto = (item) => {
        if (!item) return "/"
        if (item?.type === "page") {
            const slug = item?.page?.slug || ""
            if (slug.at(0) === "/") return slug
            return "/" + slug
        }
        return item.url
    }

    const subitems = (item: any) => {
        return (
            <ul
                className={twMerge(
                    "bg-base-100 z-50 p-2 shadow-md",
                    oSubitem.main
                )}
            >
                {item.children.map((itemChild: any, idx: number) => {
                    return (
                        <li
                            key={"M_" + name + "_L2_" + idx}
                            className={twMerge("", oSubitem.item)}
                        >
                            <Link to={goto(itemChild)} target="_blank">
                                <span className={twMerge("", oSubitem.name)}>
                                    {itemChild.name}
                                </span>
                            </Link>
                        </li>
                    )
                })}
            </ul>
        )
    }

    const items = (item: any) => {
        return (
            <ul
                className={twMerge(
                    "menu bg-base-100 rounded-box z-50 min-w-[12rem] p-2 shadow-md",
                    oItem.main
                )}
            >
                {item.children.map((itemChild: any, idx: number) => {
                    return (
                        <li
                            key={"M_" + name + "_L1_" + idx}
                            className={twMerge("", oItem.item)}
                        >
                            <Link
                                to={goto(itemChild)}
                                target="_blank"
                                className={twMerge("", oItem.link)}
                            >
                                <span className={twMerge("grow", oItem.name)}>
                                    {itemChild.name}
                                </span>
                                {itemChild?.children.length > 0 && (
                                    <ChevronRightIcon className="h-5 w-5" />
                                )}
                            </Link>
                            {itemChild?.children?.length > 0 &&
                                subitems(itemChild)}
                        </li>
                    )
                })}
            </ul>
        )
    }

    return (
        <>
            {/* MENU standart */}
            <ul className={twMerge(className, oClass.main)}>
                {menu?.map((item: any, key: number) => {
                    var url = ""
                    if (item?.page?.slug) {
                        url = "/" + item?.page?.slug
                    } else {
                        url = item?.url
                    }
                    console.log("at", item?.options?.link)

                    return (
                        <li key={"M_" + name + "_L0_" + key}>
                            <Link
                                to={goto(item)}
                                target="_blank"
                                className={twMerge(
                                    "",
                                    item.options?.link,
                                    oClass.link
                                )}
                            >
                                <span
                                    className={twMerge(
                                        "[&.active]:text-primary",
                                        oClass.name,
                                        item.options?.name,
                                        window.location.pathname == url
                                            ? "active"
                                            : ""
                                    )}
                                >
                                    {item.name}
                                </span>
                                {item?.children.length > 0 && (
                                    <ChevronDownIcon className="h-5 w-5" />
                                )}
                            </Link>
                            {item?.children?.length > 0 && items(item)}
                        </li>
                    )
                })}
                {userMenu ? <UserMenu /> : null}
            </ul>
            {/* END MENU standart */}
        </>
    )
}

export default Menu
